{% extends "layout.html" %}

{% block title %}
Section Archétypes
{% endblock %}

{% block content %}
{% trans trimmed

%}
<h1>Archétypes</h1>
<p>
	Cette section complète l'introduction au {{ deckbuilding }} et propose des
	archétypes de tournois qui ont fait leurs preuves dans des tournois d'au
	moins 40 joueurs.
</p>
{% endtrans %}
<div class="align-left">
	<table class="wide-column">
		<tbody>
			<tr>
				<td>{{ link("/archetypes/adeliz-the-cinder-wind") }}</td>
				<td>(Agro-Contrôle)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/aminatou-the-fateshifter") }}</td>
				<td>(Contrôle)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/isamaru-hound-of-konda") }}</td>
				<td>(Agro)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/golos-tireless-pilgrim") }}</td>
				<td>(Contrôle)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/kess-dissident-mage") }}</td>
				<td>(Contrôle)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/kelsien-the-plague") }}</td>
				<td>(Agro)</td>
			</tr>
		</tbody>
	</table>
	<table class="wide-column">
		<tbody>
			<tr>
				<td>{{ link("/archetypes/rowan-and-will-kenrith") }}</td>
				<td>(Contrôle)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/the-gitrog-monster") }}</td>
				<td>(Contrôle-Combo)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/titania-protector-of-argoth") }}</td>
				<td>(Agro)</td>
			</tr>
			<tr>
				<td>{{ link("/archetypes/winota-joiner-of-forces") }}</td>
				<td>(Agro-Combo)</td>
			</tr>
			<tr>
				<td colspan=2><em>D'autres analyses à venir</em></td>
			</tr>
		</tbody>
	</table>
</div>
{% trans trimmed
	systeme_e=link("/articles/lart-de-classifier-les-decks/classification-en-macrotypes", _("Système E"), _anchor="classification_hybride")
%}
<p>
	Les <em>macrotypes</em> utilisés pour les decks ci-dessus correspondent aux macrotypes décrits
	dans le {{ systeme_e }}.
	Les <em>archéypes</em> ne sont pas affichés car les decks créent leur propre archétype dans la
	majeure partie des situations.
</p>
{% endtrans %}
{% endblock %}
